@@ -25,7 +25,7 @@ use Image::Magick;
 use File::ShareDir qw/dist_dir/;
 binmode(STDOUT,':utf8');
 
-our $VERSION = 0.29;
+our $VERSION = 0.31;
 
 =head1 NAME
 
@@ -1473,7 +1473,7 @@ sub Img2JPG {
      }
   }
 
-  $Image->Write($To);
+  $Image->[0]->Write($To);
 
   unless (-s $To) {
     $X->Error("Cant't convert $ImgFile to JPG");
